Smoothers
=========

.. automodule:: stonesoup.smoother
    :no-members:

.. automodule:: stonesoup.smoother.base
    :show-inheritance:

Linear Gaussian
---------------

.. automodule:: stonesoup.smoother.lineargaussian
    :show-inheritance:


